﻿'
' Will Strohl (wills@strohlsitedesign.com)
' http://www.willstrohl.com
'
'Copyright (c) 2010, Will Strohl
'All rights reserved.
'
'Redistribution and use in source and binary forms, with or without modification, are 
'permitted provided that the following conditions are met:
'
'Redistributions of source code must retain the above copyright notice, this list of 
'conditions and the following disclaimer.
'
'Redistributions in binary form must reproduce the above copyright notice, this list 
'of conditions and the following disclaimer in the documentation and/or other 
'materials provided with the distribution.
'
'Neither the name of StrohlSiteDesign.com nor the names of its contributors may be 
'used to endorse or promote products derived from this software without specific prior 
'written permission.
'
'THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
'EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
'OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
'SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
'INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
'TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
'BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
'CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
'ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
'DAMAGE.
'

Imports DotNetNuke.Services.Exceptions
Imports System.Web.UI

Namespace WillStrohl.Modules.QueryToGrid

    Partial Public MustInherit Class ViewGridJQuery
        Inherits WNSPortalModuleBase

#Region " Private Members "

        Private p_AjaxUrl As String = Null.NullString
        Private p_TimeHandlerUrl As String = Null.NullString

#End Region

#Region " Private Properties "

        Protected ReadOnly Property AjaxUrl() As String
            Get
                If Not String.IsNullOrEmpty(Me.p_AjaxUrl) Then
                    Return Me.p_AjaxUrl
                End If

                If Request.IsSecureConnection Then
                    Me.p_AjaxUrl = "https://"
                Else
                    Me.p_AjaxUrl = "http://"
                End If

                Me.p_AjaxUrl = String.Concat(Me.p_AjaxUrl, Me.PortalAlias.HTTPAlias, Me.ControlPath, "Query.ashx")

                Return Me.p_AjaxUrl
            End Get
        End Property

        Protected ReadOnly Property TimeHandlerUrl() As String
            Get
                If Not String.IsNullOrEmpty(Me.p_TimeHandlerUrl) Then
                    Return Me.p_TimeHandlerUrl
                End If

                If Request.IsSecureConnection Then
                    Me.p_TimeHandlerUrl = "https://"
                Else
                    Me.p_TimeHandlerUrl = "http://"
                End If

                Me.p_TimeHandlerUrl = String.Concat(Me.p_TimeHandlerUrl, Me.PortalAlias.HTTPAlias, Me.ControlPath, "Time.ashx")

                Return Me.p_TimeHandlerUrl
            End Get
        End Property

#End Region

#Region " Event Handlers "

        Private Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load

            Try

                If Not Me.Page.IsPostBack Then
                    Me.BindData()
                End If

                Me.lblPageLoadTime.Text = DateTime.Now.ToString("hh:mm:ss tt")

                ' request that the DNN framework load the jQuery script into the markup
                DotNetNuke.Framework.jQuery.RequestRegistration()

                Dim strJQueryUI As String = String.Format( _
                    "<script language=""javascript"" type=""text/javascript"" src=""{0}""></script>", _
                    String.Concat(Me.ControlPath, "js/jquery-ui.min.js"))

                ' Load jQuery UI on every page load
                If Not Page.ClientScript.IsClientScriptBlockRegistered("jquery.ui") Then
                    Page.ClientScript.RegisterClientScriptBlock( _
                        Me.GetType, _
                        "jquery.ui", _
                        strJQueryUI, _
                        False)
                End If

                Dim strDatatables As String = String.Format( _
                    "<script language=""javascript"" type=""text/javascript"" src=""{0}""></script>", _
                    String.Concat(Me.ControlPath, "js/dataTables/media/js/jquery.dataTables.min.js"))

                ' Load the AutoComplete plugin script on every page load
                If Not Page.ClientScript.IsClientScriptBlockRegistered("jquery.datatables") Then
                    Page.ClientScript.RegisterClientScriptBlock( _
                        Me.GetType, _
                        "jquery.datatables", _
                        strDatatables, _
                        False)
                End If

                Me.Page.Header.Controls.Add(New LiteralControl("<link rel=""stylesheet"" type=""text/css"" href=""http://ajax.googleapis.com/ajax/libs/jqueryui/1.7.2/themes/start/jquery-ui.css"" />"))

                Me.Page.Header.Controls.Add(New LiteralControl(String.Format("<link rel=""stylesheet"" type=""text/css"" href=""{0}"" />", String.Concat(Me.ControlPath, "js/dataTables/media/css/demo_table.css"))))
                Me.Page.Header.Controls.Add(New LiteralControl(String.Format("<link rel=""stylesheet"" type=""text/css"" href=""{0}"" />", String.Concat(Me.ControlPath, "js/dataTables/media/css/demo_table_jui.css"))))

            Catch exc As Exception ' Module failed to load
                ProcessModuleLoadException(Me, exc, Me.IsEditable)
            End Try

        End Sub

#End Region

#Region " Helper Methods "

        Private Sub BindData()

            Me.LocalizeModule()

            Me.lblOriginalPageLoadTime.Text = DateTime.Now.ToString("hh:mm:ss tt")

        End Sub

        Private Sub LocalizeModule()

            Me.lnkGridDefault.Text = Me.GetLocalizedString("lnkGridDefault.Text")
            Me.lnkGridPartialRendering.Text = Me.GetLocalizedString("lnkGridPartialRendering.Text")
            Me.lnkGridJQuery.Text = Me.GetLocalizedString("lnkGridJQuery.Text")
            Me.lnkTelerik.Text = Me.GetLocalizedString("lnkTelerik.Text")

        End Sub

        Private Sub lnkGridDefault_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles lnkGridDefault.Click
            Me.SendTo(NavigateURL)
        End Sub

        Private Sub lnkGridJQuery_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles lnkGridJQuery.Click
            Me.SendTo(EditUrl(Null.NullString, Null.NullString, "jQuery"))
        End Sub

        Private Sub lnkGridPartialRendering_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles lnkGridPartialRendering.Click
            Me.SendTo(EditUrl(Null.NullString, Null.NullString, "Partial"))
        End Sub

        Private Sub lnkTelerik_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles lnkTelerik.Click
            Me.SendTo(EditUrl(Null.NullString, Null.NullString, "Telerik"))
        End Sub

#End Region

    End Class

End Namespace